.. index::
   single: Monte Carlo; Calculators

.. module:: mchammer.calculators

Calculators
===========


.. _cluster_expansion_calculator:

.. index::
   single: Function reference; ClusterExpansionCalculator
   single: Class reference; ClusterExpansionCalculator
   single: Monte Carlo; Cluster expansion calculator

ClusterExpansionCalculator
--------------------------

.. autoclass:: ClusterExpansionCalculator
   :members:
   :undoc-members:
   :inherited-members:

.. _constituent_strain_calculator:

.. index::
   single: Function reference; ConstituentStrainCalculator
   single: Class reference; ConstituentStrainCalculator
   single: Monte Carlo; Constituent strain calculator

ConstituentStrainCalculator
---------------------------

.. autoclass:: ConstituentStrainCalculator
   :members:
   :undoc-members:
   :inherited-members:


.. _target_vector_calculator:

.. index::
   single: Function reference; TargetVectorCalculator
   single: Class reference; TargetVectorCalculator
   single: Monte Carlo; Target vector calculator

TargetVectorCalculator
--------------------------

.. autoclass:: mchammer.calculators.TargetVectorCalculator
   :members:
   :undoc-members:
   :inherited-members:

.. autofunction:: mchammer.calculators.compare_cluster_vectors